aboutsummaryrefslogtreecommitdiff
path: root/src/lib/protocols/edonkey.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/protocols/edonkey.c')
-rw-r--r--src/lib/protocols/edonkey.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/protocols/edonkey.c b/src/lib/protocols/edonkey.c
index be1fae412..4dcc85ec9 100644
--- a/src/lib/protocols/edonkey.c
+++ b/src/lib/protocols/edonkey.c
@@ -159,8 +159,8 @@ static void ndpi_check_edonkey(struct ndpi_detection_module_struct *ndpi_struct,
struct ndpi_packet_struct *packet = &ndpi_struct->packet;
u_int32_t payload_len = packet->payload_packet_len;
- /* Break after 20 packets. */
- if(flow->packet_counter > 20) {
+ /* Break after 10 packets. */
+ if(flow->packet_counter > 10) {
NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
return;
}